aboutsummaryrefslogtreecommitdiffstats
path: root/common/nextpnr.h
diff options
context:
space:
mode:
Diffstat (limited to 'common/nextpnr.h')
-rw-r--r--common/nextpnr.h28
1 files changed, 16 insertions, 12 deletions
diff --git a/common/nextpnr.h b/common/nextpnr.h
index e9e491f4..5e32d5b6 100644
--- a/common/nextpnr.h
+++ b/common/nextpnr.h
@@ -145,21 +145,25 @@ struct GraphicElement
{
enum type_t
{
- G_NONE,
- G_LINE,
- G_ARROW,
- G_BOX,
- G_CIRCLE,
- G_LABEL
- } type = G_NONE;
+ TYPE_NONE,
+ TYPE_LINE,
+ TYPE_ARROW,
+ TYPE_BOX,
+ TYPE_CIRCLE,
+ TYPE_LABEL,
+
+ TYPE_MAX
+ } type = TYPE_NONE;
enum style_t
{
- G_FRAME, // Static "frame". Contrast between G_INACTIVE and G_ACTIVE
- G_HIDDEN, // Only display when object is selected or highlighted
- G_INACTIVE, // Render using low-contrast color
- G_ACTIVE, // Render using high-contast color
- } style = G_FRAME;
+ STYLE_FRAME, // Static "frame". Contrast between STYLE_INACTIVE and STYLE_ACTIVE
+ STYLE_HIDDEN, // Only display when object is selected or highlighted
+ STYLE_INACTIVE, // Render using low-contrast color
+ STYLE_ACTIVE, // Render using high-contast color
+
+ STYLE_MAX
+ } style = STYLE_FRAME;
float x1 = 0, y1 = 0, x2 = 0, y2 = 0, z = 0;
std::string text;